# clldutils

Utilities for clld apps without the overhead of requiring pyramid, rdflib et al.

[![Build Status](https://github.com/clld/clldutils/workflows/tests/badge.svg)](https://github.com/clld/clldutils/actions?query=workflow%3Atests)
[![codecov.io](https://codecov.io/github/clld/clldutils/coverage.svg?branch=master)](https://codecov.io/github/clld/clldutils?branch=master)
[![Requirements Status](https://requires.io/github/clld/clldutils/requirements.svg?branch=master)](https://requires.io/github/clld/clldutils/requirements/?branch=master)
[![PyPI](https://img.shields.io/pypi/v/clldutils.svg)](https://pypi.python.org/pypi/clldutils)


## Manipulating "Standard Format" (SFM, a.k.a. toolbox) files

- [`clldutils.sfm`](clldutils/sfm.py)
